@@ -364,7 +364,7 @@ void onefield_run(onefield_t* bp) {
         // logodds-to-solve impossibly high so that a "good enough" solution doesn't
         // stop us from continuing to search...
         double oldodds = bp->logratio_tosolve;
-        bp->logratio_tosolve = HUGE_VAL;
+        bp->logratio_tosolve = LARGE_VAL;
 
         for (w = 0; w < bl_size(bp->verify_wcs_list); w++) {
             double pixscale;
@@ -1065,8 +1065,8 @@ void onefield_matchobj_deep_copy(const MatchObj* mo, MatchObj* dest) {
             tagcopy.name = strdup_safe(tag->name);
             tagcopy.units = strdup_safe(tag->units);
             if (tag->data) {
-                tagcopy.data = malloc(tag->Ndata * tag->itemsize);
-                memcpy(tagcopy.data, tag->data, tag->Ndata * tag->itemsize);
+                tagcopy.data = malloc((size_t)tag->Ndata * (size_t)tag->itemsize);
+                memcpy(tagcopy.data, tag->data, (size_t)tag->Ndata * (size_t)tag->itemsize);
             }
             bl_append(dest->tagalong, &tagcopy);
         }
