@@ -24,6 +24,7 @@
 #include "errors.h"
 #include "log.h"
 #include "errors.h"
+#include "mathutil.h"
 
 Malloc
 char* fits_to_string(const qfits_header* hdr, int* size) {
@@ -307,7 +308,7 @@ double fits_get_double_val(const qfits_table* table, int column,
     } else {
         fprintf(stderr, "Invalid column type %i.\n", table->col[column].atom_type);
     }
-    return HUGE_VAL;
+    return LARGE_VAL;
 }
 
 int fits_is_table_header(const char* key) {
@@ -968,7 +969,7 @@ int fits_write_data_array(FILE* fid, const void* vvalue, tfits_type type,
     const char* pvalue = (const char*)vvalue;
 
     if (pvalue == NULL) {
-        if (fseeko(fid, fits_get_atom_size(type) * N, SEEK_CUR)) {
+        if (fseeko(fid, (size_t)fits_get_atom_size(type) * (size_t)N, SEEK_CUR)) {
             fprintf(stderr, "Failed to skip %i bytes in fits_write_data_array: %s\n",
                     fits_get_atom_size(type) * N, strerror(errno));
             return -1;
